import { useCallback, useMemo } from 'react'
import { Button, Card, CardActions, CardContent, CardHeader, TextField } from '@mui/material'
import { useResetPasswordMutation } from '../graphql'
import { useHistory, useLocation } from 'react-router-dom'

function ResetPassword() {
  const [reset] = useResetPasswordMutation()
  const location = useLocation()
  const history = useHistory()
  const token = useMemo(() => new URLSearchParams(location.search).get('token') || '', [location.search])
  const handleSubmit = useCallback(async (evt: React.FormEvent) => {
    evt.preventDefault()
    const password = (evt.target as any).elements.password.value
    await reset({ variables: { password, token } })
    history.push('/login')
  }, [reset, token, history])

  return <Card component="form" onSubmit={handleSubmit}>
    <CardHeader title="Reset your password" titleTypographyProps={{ variant: 'h5', gutterBottom: true }} />
    <CardContent>
      <TextField variant="filled" label="Password" name="password" type="password" margin="normal" fullWidth />
      <TextField variant="filled" label="Confirm password" name="confirm" type="password" margin="normal" fullWidth />
    </CardContent>
    <CardActions sx={{ justifyContent: 'end' }}>
      <Button variant="contained" size="large" type="submit">Reset</Button>
    </CardActions>
  </Card>
}

export default ResetPassword
