import { useCallback } from 'react'
import { Button, Card, CardActions, CardContent, CardHeader, TextField } from '@mui/material'
import { useLoginMutation } from '../graphql'
import { useHistory } from 'react-router-dom'

function Login() {
  const [login] = useLoginMutation()
  const history = useHistory()
  const handleSubmit = useCallback(async (evt: React.FormEvent) => {
    evt.preventDefault()
    const password = (evt.target as any).elements.password.value
    const email = (evt.target as any).elements.email.value
    const result = await login({ variables: { email, password } })
    if(result.data){
      localStorage.setItem('AUTH_TOKEN', result.data?.login.accessToken)
      history.push('/')
    }
  }, [login, history])

  return <Card component="form" onSubmit={handleSubmit}>
    <CardHeader title="Login" titleTypographyProps={{ variant: 'h5', gutterBottom: true }} />
    <CardContent>
      <TextField variant="filled" label="E-mail" name="email" margin="normal" fullWidth />
      <TextField variant="filled" label="Password" name="password" type="password" margin="normal" fullWidth />
    </CardContent>
    <CardActions sx={{ justifyContent: 'end' }}>
      <Button variant="contained" size="large" type="submit">Login</Button>
    </CardActions>
  </Card>
}

export default Login
